diff --git a/compiler/generic/vm-fndb.lisp b/compiler/generic/vm-fndb.lisp
index 5b48510bfb936a1d7b6ff5b88ec0962b9d1316f4..7ade474155b7b38cea0fd76bd9b7ae106e9cb61a 100644
--- a/compiler/generic/vm-fndb.lisp
+++ b/compiler/generic/vm-fndb.lisp
@@ -7,11 +7,11 @@
 ;;; Scott Fahlman or slisp-group@cs.cmu.edu.
 ;;;
 (ext:file-comment
-  "$Header: /Volumes/share2/src/cmucl/cvs2git/cvsroot/src/compiler/generic/vm-fndb.lisp,v 1.41 1991/11/25 00:00:58 wlott Exp $")
+  "$Header: /Volumes/share2/src/cmucl/cvs2git/cvsroot/src/compiler/generic/vm-fndb.lisp,v 1.42 1992/03/07 17:14:17 wlott Exp $")
 ;;;
 ;;; **********************************************************************
 ;;;
-;;; $Header: /Volumes/share2/src/cmucl/cvs2git/cvsroot/src/compiler/generic/vm-fndb.lisp,v 1.41 1991/11/25 00:00:58 wlott Exp $
+;;; $Header: /Volumes/share2/src/cmucl/cvs2git/cvsroot/src/compiler/generic/vm-fndb.lisp,v 1.42 1992/03/07 17:14:17 wlott Exp $
 ;;;
 ;;; This file defines the machine specific function signatures.
 ;;;
@@ -261,12 +261,19 @@
   ())
 
 
 ;;;; Code object manipulation routines.
 
 (defknown code-instructions (t) system-area-pointer (flushable movable))
 (defknown code-header-ref (t index) t (flushable))
 (defknown code-header-set (t index t) t ())
 
+(defknown make-fdefn (t) fdefn (flushable movable))
+(defknown fdefn-p (t) boolean (movable foldable flushable))
+(defknown fdefn-name (fdefn) t (foldable flushable))
+(defknown fdefn-function (fdefn) (or function null) (flushable))
+(defknown (setf fdefn-function) (function fdefn) t (unsafe))
+(defknown fdefn-makunbound (fdefn) t ())
+
 
 
 ;;;; Mutator accessors.
@@ -261,12 +261,19 @@
 
 
-;;;; Code object manipulation routines.
+;;;; Code/function/fdefn object manipulation routines.
 
 (defknown code-instructions (t) system-area-pointer (flushable movable))